@@ -86,6 +86,10 @@ class RedisSessionInterface(SessionInterface):
                                 expires=cookie_exp,
                                 httponly=True,
                                 domain=domain)
-            response.set_cookie('locale', session.get('locale'))
+            response.set_cookie('locale', session.get('locale'),
+                                expires=cookie_exp,
+                                httponly=True,
+                                domain=domain
+                                )
             # 确保下次正常时需要
             session.seend_cookie = False
